/*
 * BOOKGUID.H
 *
 * CLSIDs and IIDs defined for Inside OLE.  This file centralizes
 * them all so we can keep track of which ones are used.  The IDs
 * in this file are for exclusive use of the author and should not
 * be used under any circumstances in any other projects.
 *
 * Copyright (c)1993-1995 Microsoft Corporation, All Rights Reserved
 *
 * Kraig Brockschmidt, Microsoft
 * Internet  :  kraigb@microsoft.com
 * Compuserve:  >INTERNET:kraigb@microsoft.com
 */


#ifndef _BOOKGUID_H_
#define _BOOKGUID_H_

#ifdef INITGUIDS
#include <initguid.h>
#endif //INITGUIDS



/*
 * GUIDs
 *
 * For this book the author has been allocated the GUIDs in the range:
 *     00021100-0000-0000-C000-000000000046
 *     000211FF-0000-0000-C000-000000000046
 *
 * Gaps in the sequences are GUIDS used by the author for purposes other
 * than this book, e.g. magazine articles.
 *
 * GUIDs between 00021100 and 0002113F were used for the first edition
 * of Inside OLE 2 and interim samples.  Those starting with 00021140
 * are for the second edition of Inside OLE.
 *
 * GUIDs are only included if a "CHAPTERx" synmbol is defined.  This
 * keeps unused GUIDs out of the compilation.
 */


//Chapter 2
#ifdef CHAPTER2
DEFINE_GUID(IID_IEnumRECT,  0x00021140, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_ISampleOne, 0x00021141, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_ISampleTwo, 0x00021142, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_IAnimal,    0x00021143, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_IKoala,     0x00021144, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
#endif


//Chapter 4
#ifdef CHAPTER4
DEFINE_GUID(IID_IDuckEvents, 0x00021145, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
#endif


//Chapter 5
#ifdef CHAPTER5

//Koala Objects
DEFINE_GUID(CLSID_Koala, 0x00021146, 0, 0, 0xC0,0,0,0,0,0,0,0x46);

//Polyline
DEFINE_GUID(CLSID_Polyline5,          0x00021147, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_IPolyline5,           0x00021148, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_IPolylineAdviseSink5, 0x00021149, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
#endif

/*****************
 ** OLD SECTION **
 *****************/


//Polyine


//Patron Files for Chapter 5 and beyond:  becomes Patron's App ID
DEFINE_GUID(CLSID_PatronPages, 0x00021106, 0, 0, 0xC0,0,0,0,0,0,0,0x46);

//Cosmo Figures/Files for Chapter 5 and beyond
#ifndef GUIDS_FROM_TYPELIB
DEFINE_GUID(CLSID_Cosmo2Figure, 0x00021107, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
#endif  //GUIDS_FROM_TYPELIB

//Polyine
//DEFINE_GUID(CLSID_Polyline5,          0x00021108, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
//DEFINE_GUID(IID_IPolyline5,           0x00021109, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
//DEFINE_GUID(IID_IPolylineAdviseSink5, 0x0002110A, 0, 0, 0xC0,0,0,0,0,0,0,0x46);


//GUIDs for Chapter 6

//DataObject variations for the data set.  Same server supplies them all.
DEFINE_GUID(CLSID_DataObjectSmall,  0x0002110B, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(CLSID_DataObjectMedium, 0x0002110C, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(CLSID_DataObjectLarge,  0x0002110D, 0, 0, 0xC0,0,0,0,0,0,0,0x46);

//Polyine
DEFINE_GUID(CLSID_Polyline6,          0x0002110E, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_IPolyline6,           0x0002110F, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_IPolylineAdviseSink6, 0x00021110, 0, 0, 0xC0,0,0,0,0,0,0,0x46);


//GUIDS for Chapter 7

//Data Transfer Component Object
DEFINE_GUID(CLSID_DataTransferObject, 0x00021111, 0, 0, 0xC0,0,0,0,0,0,0,0x46);

#ifndef WIN32
//OLE32 has these defined, OLE16 doesn't
#undef CLSID_Picture_Metafile
#undef CLSID_Picture_Dib
DEFINE_OLEGUID(CLSID_Picture_Metafile,        0x00000315, 0, 0);
DEFINE_OLEGUID(CLSID_Picture_Dib,             0x00000316, 0, 0);
#endif

//Cosmo in chapter 10 uses CLSID_Cosmo2Figure above.


//GUIDs for Chapter 11

//HCosmo is registered under CLSID_Cosmo2Figure

//Polyine
DEFINE_GUID(CLSID_Polyline11, 0x00021112, 0, 0, 0xC0,0,0,0,0,0,0,0x46);


//GUIDs for Chapter 12

//LinksAssistant
DEFINE_GUID(CLSID_LinksAssistant, 0x00021113, 0, 0, 0xC0,0,0,0,0,0,0,0x46);

//OLE 2.0 SDK forgot this one.
DEFINE_GUID(IID_IOleUILinkContainer, 0x00021114, 0, 0, 0xC0,0,0,0,0,0,0,0x46);


//GUIDs for Chapter 16

/*
 * Cosmo in chapter 16 uses CLSID_Cosmo2Figure above.
 * Polyine in Chapter 16 uses CLSID_Polyline11.
 *
 * This is so we don't make repeat entries in the
 * registration database.
 */


//NEW SECTION
//Chapter 13

//Beeper samples
#ifndef GUIDS_FROM_TYPELIB
DEFINE_GUID(CLSID_Beeper,            0x00021125, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_IBeeper,             0x00021126, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(DIID_DIBeeper,           0x00021127, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(LIBID_BeeperTypeLibrary, 0x00021128, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
#endif


//Cosmo Chapter 13:  Automation Interfaces
#ifndef GUIDS_FROM_TYPELIB
DEFINE_GUID(IID_ICosmoApplication,    0x00021129, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_ICosmoFigures,        0x0002112A, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_ICosmoFigure,         0x0002112B, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(DIID_DICosmoApplication,  0x0002112C, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(DIID_DICosmoFigures,      0x0002112D, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(DIID_DICosmoFigure,       0x0002112E, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(LIBID_Cosmo2TypeLibrary,  0x0002112F, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(CLSID_Cosmo2Application,  0x00021130, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
#endif


//Chapter 14

//Range 0x00021115-0x00021119 reserved for other uses.

//SphereSquare Automation Object
#ifndef GUIDS_FROM_TYPELIB
DEFINE_GUID(CLSID_SphereSquare,   0x00021120, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(IID_ISphereSquare,    0x00021121, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(TLBID_SphereSquare,   0x00021122, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(DIID_DISphereSquare,  0x00021131, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
#endif

//Reserved for now.
DEFINE_GUID(IID_IPatronAmbients,  0x00021123, 0, 0, 0xC0,0,0,0,0,0,0,0x46);
DEFINE_GUID(TLBID_PatronControls, 0x00021124, 0, 0, 0xC0,0,0,0,0,0,0,0x46);


#endif //_BOOKGUID_H_
